Skip to contents

Layer summary table

Usage

at_layers(project, call = rlang::caller_env())

Arguments

project

An annot_project.

call

The calling environment, for error reporting.

Value

A tibble::tibble with one row per layer and the columns name (character), n_rois (integer), labels (list of character), visible (logical), locked (logical), and z (integer). A 0-row tibble with these columns when the project has no layers.