Load a project
Usage
at_load_project(path, call = rlang::caller_env())Value
The annot_project. Warns if the file was written by a newer annotatR.
Load a project
at_load_project(path, call = rlang::caller_env())The annot_project. Warns if the file was written by a newer annotatR.