Nearest-neighbour downsample only (interpolating a label mask would invent labels that do not exist).
Usage
at_mask_preview(mask, max_dim = 1024L, call = rlang::caller_env())Nearest-neighbour downsample only (interpolating a label mask would invent labels that do not exist).
at_mask_preview(mask, max_dim = 1024L, call = rlang::caller_env())